@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
-/* Copyright (C) 2018-2023 Hans Petter Jansson
+/* Copyright (C) 2018-2025 Hans Petter Jansson
  *
  * This file is part of Chafa, a program that shows pictures on text terminals.
  *
@@ -1271,6 +1271,7 @@ draw_all_pixels (ChafaCanvas *canvas, ChafaPixelType src_pixel_type,
                  const guint8 *src_pixels,
                  gint src_width, gint src_height, gint src_rowstride)
 {
+    ChafaColor bg_color;
     ChafaAlign halign = CHAFA_ALIGN_START, valign = CHAFA_ALIGN_START;
     ChafaTuck tuck = CHAFA_TUCK_STRETCH;
 
@@ -1292,6 +1293,13 @@ draw_all_pixels (ChafaCanvas *canvas, ChafaPixelType src_pixel_type,
 
     destroy_pixel_canvas (canvas);
 
+    if (canvas->config.pixel_mode == CHAFA_PIXEL_MODE_KITTY
+        || canvas->config.pixel_mode == CHAFA_PIXEL_MODE_ITERM2)
+    {
+        chafa_unpack_color (canvas->config.bg_color_packed_rgb, &bg_color);
+        bg_color.ch [3] = canvas->config.alpha_threshold < 1 ? 0x00 : 0xff;
+    }
+
     if (canvas->config.pixel_mode == CHAFA_PIXEL_MODE_SYMBOLS)
     {
         /* Symbol mode */
@@ -1317,7 +1325,11 @@ draw_all_pixels (ChafaCanvas *canvas, ChafaPixelType src_pixel_type,
                                                   src_width, src_height,
                                                   src_rowstride,
                                                   canvas->pixels,
-                                                  canvas->width_pixels, canvas->height_pixels);
+                                                  canvas->width_pixels, canvas->height_pixels,
+                                                  canvas->config.cell_width,
+                                                  canvas->config.cell_height,
+                                                  halign, valign,
+                                                  tuck);
 
             if (canvas->config.alpha_threshold == 0)
                 canvas->have_alpha = FALSE;
@@ -1352,15 +1364,11 @@ draw_all_pixels (ChafaCanvas *canvas, ChafaPixelType src_pixel_type,
                                             src_width, src_height,
                                             src_rowstride,
                                             halign, valign,
-                                            tuck);
+                                            tuck,
+                                            canvas->config.work_factor);
     }
     else if (canvas->config.pixel_mode == CHAFA_PIXEL_MODE_KITTY)
     {
-        ChafaColor bg_color;
-
-        chafa_unpack_color (canvas->config.bg_color_packed_rgb, &bg_color);
-        bg_color.ch [3] = canvas->config.alpha_threshold < 1 ? 0x00 : 0xff;
-
         /* Kitty mode */
 
         canvas->fg_palette.alpha_threshold = canvas->config.alpha_threshold;
@@ -1391,6 +1399,7 @@ draw_all_pixels (ChafaCanvas *canvas, ChafaPixelType src_pixel_type,
                                                  src_pixels,
                                                  src_width, src_height,
                                                  src_rowstride,
+                                                 bg_color,
                                                  halign, valign,
                                                  tuck);
     }
@@ -1440,11 +1449,6 @@ chafa_canvas_new (const ChafaCanvasConfig *config)
         /* Sixels */
         canvas->width_pixels = canvas->config.width * canvas->config.cell_width;
         canvas->height_pixels = canvas->config.height * canvas->config.cell_height;
-
-        /* Ensure height is the biggest multiple of 6 that will fit
-         * in our cells. We don't want a fringe going outside our
-         * bottom cell. */
-        canvas->height_pixels -= canvas->height_pixels % 6;
     }
     else  /* CHAFA_PIXEL_MODE_KITTY or CHAFA_PIXEL_MODE_ITERM2 */
     {
@@ -1876,6 +1880,8 @@ chafa_canvas_print_rows (ChafaCanvas *canvas, ChafaTermInfo *term_info,
         if (array_len_out)
             *array_len_out = 1;
     }
+
+    chafa_term_info_unref (term_info);
 }
 
 /**
